//
//  CombineViewModel.swift
//  Intermediate SwiftUI
//
//  Created by Johan Sas on 19/09/2024.
//

import Combine
import SwiftUI

class CombineViewModel: ObservableObject {
    @Published var combinedData: String = ""
    
    private var cancellable: AnyCancellable?
    
    func fetchAndCombineData() {
        let apiPublisher = URLSession.shared.dataTaskPublisher(for: URL(string: "https://jsonplaceholder.typicode.com/posts/1")!)
            .map { data , _ in
                return String(data: data, encoding: .utf8) ?? "No Data"
            }
            .replaceError(with: "Failed to Fetch Data")
        
        let timerPublisher = Timer.publish(every: 1.0, on: .main, in: .common)
            .autoconnect()
            .map { "Local Time: \(TimerViewModel().dateFormatter.string(from: $0))"
            }
        cancellable = Publishers.CombineLatest(apiPublisher, timerPublisher)
            .map { apiData, timeData in
                return "\(timeData)\nAPI Data: \(apiData)"
            }
            .sink { [ weak self] data in
                self!.combinedData = data
            }
    }
}
