import SwiftUI
import CoreData

struct CoreDataView: View {
    @Environment(\.managedObjectContext) private var viewContext
    @FetchRequest(fetchRequest: Item.getAllItemsRequest())
    private var items: FetchedResults<Item>
    
    @State var newItemName = ""
    
    var body: some View {
        VStack {
            HStack {
                TextField("Enter new Item", text: $newItemName)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
                Button(action: addItem) {
                    Label("Add Item", systemImage: "plus")
                }
            }
            .padding()
            
            List {
                ForEach(items, id: \.self) { item in
                    VStack(alignment: .leading) {
                        Text(item.name ?? "Unnamed")
                        Text("\(item.timestamp ?? Date())")
                            .font(.subheadline)
                            .foregroundStyle(.gray)
                    }
                }.onDelete(perform: deleteItem)
            }
        }
    }
    
    private func addItem() {
        withAnimation {
            let newItem = Item(context: viewContext)
            newItem.name = newItemName
            newItem.timestamp = Date()
            
            do {
                try viewContext.save()
            } catch {
                let nsError = error as NSError
                fatalError("Unresolved error \(nsError), \(nsError.userInfo)")
            }
            // Resetting the correct property
            newItemName = ""
        }
    }
    
    private func deleteItem(offsets: IndexSet) {
        withAnimation {
            offsets.map {
                items[$0]
            }.forEach(viewContext.delete)
            
            do {
                try viewContext.save()
            } catch {
                let nsError = error as NSError
                fatalError("Unresolved error \(nsError), \(nsError.userInfo)")
            }
        }
    }
}

#Preview {
    
    CoreDataView()
        .environment(\.managedObjectContext, PersistenceController.shared.container.viewContext)
}
