//
//  Networking.swift
//  Intermediate SwiftUI
//
//  Created by Johan Sas on 19/09/2024.
//

import SwiftUI

struct Networking: View {
    
    @ObservedObject var postFetcher = PostFetcher()
    
    var body: some View {
        NavigationStack {
            if postFetcher.isLoading {
                ProgressView("Loading...")
                    .progressViewStyle(CircularProgressViewStyle())
                
            } else if let errorMessage = postFetcher.errorMessage {
                Text(errorMessage)
                    .foregroundStyle(.red)
                    .multilineTextAlignment(.center)
                    .padding()
            } else {
                List(postFetcher.posts) { post in
                    HStack {
                        Text(post.title)
                            .font(.headline)
                        AsyncImage(url: URL(string: post.thumbnailUrl))
                            .font(.subheadline)
                            .foregroundStyle(.gray)
                    }.padding()
                }
                .navigationTitle("Posts")
            }
        }
        .onAppear {
            postFetcher.fetchPosts()
        }
    }
}

#Preview {
    Networking()
}
