//
//  PostFetcher.swift
//  Intermediate SwiftUI
//
//  Created by Johan Sas on 19/09/2024.
//

import Foundation
import Combine

class PostFetcher: ObservableObject {
    @Published var posts: [PostModel] = []
    @Published var isLoading = false
    @Published var errorMessage: String?
    
    
    
    private var cancellable: AnyCancellable?
    
    func fetchPosts() {
        guard let url = URL(string: "https://jsonplaceholder.typicode.com/photos") else {
            return
        }
        
        isLoading = true
        errorMessage = nil
        
        cancellable = URLSession.shared.dataTaskPublisher(for: url)
            .map {$0.data}
            .decode(type: [PostModel].self, decoder: JSONDecoder())
            .receive(on: DispatchQueue.main)
            .sink(receiveCompletion: { [weak self] completion in
                self?.isLoading = false
                switch completion {
                case .finished:
                    print("Sucessfully fetched Posts")
                case .failure(let error):
                    self?.errorMessage = "Failed to load Posts \(error.localizedDescription)"
                    print("Error fetching posts: \(error)")
                }
            }, receiveValue: {[weak self] posts in
                self?.posts = posts
            })
        
    }
}
